#!/bin/sh
( cd ./usr/lib ; rm -rf libyazthread.so )
( cd ./usr/lib ; ln -sf libyazthread.so.2.0.0 libyazthread.so )
( cd ./usr/lib ; rm -rf libyaz.so )
( cd ./usr/lib ; ln -sf libyaz.so.2.0.0 libyaz.so )
( cd ./usr/lib ; rm -rf libyaz.so.2 )
( cd ./usr/lib ; ln -sf libyaz.so.2.0.0 libyaz.so.2 )
( cd ./usr/lib ; rm -rf libyazthread.so.2 )
( cd ./usr/lib ; ln -sf libyazthread.so.2.0.0 libyazthread.so.2 )

